@@ -29,6 +29,7 @@
 #include <sys/wait.h>
 #include <netdb.h>
 #include <fcntl.h>
+#include <netinet/in.h>
 
 #include "nettool.h"
 #include "utils.h"
@@ -315,7 +316,7 @@ netinfo_io_text_buffer_dialog (GIOChannel * channel,
 			       GIOCondition condition, gpointer data)
 {
 	gchar *text = NULL;
-	gint len;
+	gsize len;
 	Netinfo *netinfo = (Netinfo *) data;
 
 	g_return_val_if_fail (channel != NULL, FALSE);
